
Welcome to Vonage's documentation!
=================================

.. toctree::
    :maxdepth: 2

    quickstart
    reference


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

